summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmdensityedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmdensityedit.h')
-rw-r--r--kpovmodeler/pmdensityedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmdensityedit.h b/kpovmodeler/pmdensityedit.h
index a8241117..514ccaf9 100644
--- a/kpovmodeler/pmdensityedit.h
+++ b/kpovmodeler/pmdensityedit.h
@@ -38,9 +38,9 @@ class PMDensityEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMDensityEdit with tqparent and name
*/
- PMDensityEdit( TQWidget* tqparent, const char* name = 0 );
+ PMDensityEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,9 +38,9 @@ class PMDensityEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMDensityEdit with tqparent and name
+ * Creates a PMDensityEdit with parent and name
*/